@@ -4,7 +4,7 @@ import asyncio
 import aiofiles
 
 async def test_aiofiles():
-    async with aiofiles.open('README.rst', 'r') as fp:
+    async with aiofiles.open('README.md', 'r') as fp:
         contents = await fp.read()
 
     assert('aiofiles' in contents)
